// Author 		: F. de la Parra
// Date			: March, 2019
// Description 	: The Query class implements the attributes and methods
//				  to navigate the HPO ontology in response to given queries.  
// Version		: 1.0

public class Query {
	int id;
	StringBuilder termPath = new StringBuilder("");
	
	// Constructors
	
	public Query(String queryText) {
		int idx = queryText.indexOf("HP:");
		id = Integer.parseInt(queryText.substring(idx + 3, idx + 10));
	}
	
	public Query(int termId) {
		id = termId;
	}
	
	// Accessors
	
	public int getId() {
		return id;
	}
	
	// Behaviour methods
	
	// This method finds all the terms to the root term, for the term
	// passed to the current query, and returns them in a single string.
	public String getTermPath(Term[] terms) {
		int tempId = id;

		// Find terms in path to the root.
		while (tempId != 1) {
			for (int i = 0; i < terms.length; i++) {
				if (terms[i].getId() == tempId) {
					termPath.append(terms[i].getTermDump() + "\n");
					tempId = terms[i].getIs_a();
					break;	
				}
			}				
		}
		
		// Add the root term.
		termPath.append(terms[0].getTermDump().trim() + "\n");
		
		return termPath.substring(0);
	}

	// This method determines the length of the path from the term passed
	// to the current query to the root term of "HPO.txt".
	public int getPathLength(Term[] terms) {
		int pathLength = 0;
		int tempId = id;
		
		// Find the length of the path to the root.
		while (tempId != 1) {
			for (int i = 0; i < terms.length; i++) {
				if (terms[i].getId() == tempId) {
					pathLength += 1;
					tempId = terms[i].getIs_a();
					break;	
				}
			}				
		}		
		return pathLength;
	}
}